Crate saola_user_facing_errors

Crate saola_user_facing_errors 

Modules

common
query_engine
schema_engine

Structs

Error
KnownError
UnknownError

Traits

SimpleUserFacingError
A less dynamic type of user-facing errors. This is used in the introspection and migration engines for simpler, more robust and helpful error handling — extra details are attached opportunistically.
UserFacingError

Functions

new_backtrace
set_panic_hook