pub struct QueryParsingFailed {
pub query_parsing_error: String,
pub query_position: String,
}Fields
query_parsing_error: StringError(s) encountered when trying to parse a query in the query engine
query_position: StringLocation of the incorrect parsing, validation in a query. Represented by tuple or object with (line, character)