pub struct RecordNotFound {
pub model_name: String,
pub argument_name: String,
pub argument_value: String,
}Fields
model_name: StringModel name from Prisma schema
argument_name: StringArgument name from a supported query on a Prisma schema model
argument_value: StringConcrete value provided for an argument on a query. Should be peeked/truncated if too long to display in the error message