pub struct StoredValueIsInvalid {
pub field_value: String,
pub field_name: String,
}Fields
field_value: StringConcrete value provided for a field on a model in Prisma schema. Should be peeked/truncated if too long to display in the error message
field_name: StringField name from one model from Prisma schema