Module validation

Module validation 

Structs

ArgumentDescription
InputTypeConstraints
InputTypeDescriptionField
OutputTypeDescription
OutputTypeDescriptionField
ValidationError
A validation error is a Serializable object that contains the path where the validation error of a certain kind ocurred, and an optional and arbitrary piece of meta-information.

Enums

InputTypeDescription
ValidationErrorKind