pub enum ValidationErrorKind {
Show 13 variants
UnexpectedRuntimeError,
EmptySelection,
InvalidArgumentType,
InvalidArgumentValue,
SomeFieldsMissing,
TooManyFieldsGiven,
SelectionSetOnScalar,
RequiredArgumentMissing,
Union,
UnknownArgument,
UnknownInputField,
UnknownSelectionField,
ValueTooLarge,
}Variants
UnexpectedRuntimeError
EmptySelection
InvalidArgumentType
InvalidArgumentValue
SomeFieldsMissing
TooManyFieldsGiven
SelectionSetOnScalar
RequiredArgumentMissing
See ValidationError::required_argument_missing and
ValidationError::conditionally_required_argument_missing
Union
UnknownArgument
UnknownInputField
UnknownSelectionField
ValueTooLarge
Implementations
Sourceimpl ValidationErrorKind
impl ValidationErrorKind
Sourcepub fn code(&self) -> &'static str
pub fn code(&self) -> &'static str
Returns the appropriate code code for the different validation errors.
TODO: Ideally each all validation errors should have the same error code (P2009), or distinct type each of them should have an individual error code. For the time being, we keep the semantics documented in the error reference as users might be relying on the error codes when subscribing to error events. Otherwise, we could be introducing a breaking change.