pub struct AzureMssqlShadowDb;Trait Implementations
Sourceimpl Debug for AzureMssqlShadowDb
impl Debug for AzureMssqlShadowDb
Sourceimpl Serialize for AzureMssqlShadowDb
impl Serialize for AzureMssqlShadowDb
Sourceimpl SimpleUserFacingError for AzureMssqlShadowDb
impl SimpleUserFacingError for AzureMssqlShadowDb
const ERROR_CODE: &'static str = "P3020"
const MESSAGE: &'static str = "The automatic creation of shadow databases is disabled on Azure SQL. Please set up a shadow database using the `shadowDatabaseUrl` datasource attribute.\nRead the docs page for more details: https://pris.ly/d/migrate-shadow"