pub trait SimpleUserFacingError {
const ERROR_CODE: &'static str;
const MESSAGE: &'static str;
}Expand description
A less dynamic type of user-facing errors. This is used in the introspection and migration engines for simpler, more robust and helpful error handling — extra details are attached opportunistically.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.